/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.cloudfarming.client.sensor;

import java.util.List;
import javax.persistence.Query;
import nl.cloudfarming.client.model.CommonModelService;
import nl.cloudfarming.client.model.SensorData;

/**
 *
 * @author Timon Veenstra
 */
public class SensorService extends CommonModelService{

    @Override
    protected String getModuleName() {
        return SensorModule.MODULE_NAME;
    }

    /**
     * Finds unlinked sensor data in a box by evaluating
     * minx <= longitude <= maxx
     * and
     * miny <= latitude <= maxy
     *
     * @param minx
     * @param maxx
     * @param miny
     * @param maxy
     * @return list with unlinked sensor data that where int the box
     */
    public List<SensorData> findUnlinkedSensorDataInBox(double minx, double maxx, double miny, double maxy) {
        startTransaction();

        Query query = getEntityManager().createQuery("select s from SensorData s "
                + "where s.sensorRun is null "
                + "and s.longitude <= :maxx "
                + "and s.longitude >= :minx "
                + "and s.latitude <= :maxy "
                + "and s.latitude >= :miny ");
        query.setParameter("minx", minx);
        query.setParameter("maxx", maxx);
        query.setParameter("miny", miny);
        query.setParameter("maxy", maxy);
        List<SensorData> result = query.getResultList();

        return result;
    }

}
